==> beast-trans-api-2.3.7-20250311.115145-22-sources.jar: com/thebeastshop/trans/vo/order/ai/TsOrderAiPackageVO.java <==
package com.thebeastshop.trans.vo.order.ai;

import com.thebeastshop.common.BaseDO;

import java.util.List;

/**
 * @author xiang.gao
 * @date 2025/3/10 19:17
 */
public class TsOrderAiPackageVO extends BaseDO {

    /**
     * 包裹序号
     */
    private String packageCode;

    /**
     * 包裹状态
     */
    private String packageStatus;

    /**
     * 配送信息
     */
    private List<String> deliveryInfo;

    /**
     * 预计发货日期
     */
    private String planedDeliveryDate;

    /**
     * 期望送达日期
     */
    private String expectedSendDate;

    /**
     * 是否转门店
     */
    private String forwardStore;

    /**
     * 是否有留言卡
     */
    private String hasMessageCard;

    /**
     * 收货人
     */
    private String receiver;

    /**
     * 收货电话
     */
    private String receiverPhone;

    /**
     * 收货城市
     */
    private String receiverCity;

    /**
     * 收获地址
     */
    private String receiverAddress;

    /**
     * 商品信息
     */
    private List<TsOrderAiProductVO> packageProducts;

    public String getPackageCode() {
        return packageCode;
    }

    public void setPackageCode(String packageCode) {
        this.packageCode = packageCode;
    }

    public String getPackageStatus() {
        return packageStatus;
    }

    public void setPackageStatus(String packageStatus) {
        this.packageStatus = packageStatus;
    }

    public List<String> getDeliveryInfo() {
        return deliveryInfo;
    }

    public void setDeliveryInfo(List<String> deliveryInfo) {
        this.deliveryInfo = deliveryInfo;
    }

    public String getPlanedDeliveryDate() {
        return planedDeliveryDate;
    }

    public void setPlanedDeliveryDate(String planedDeliveryDate) {
        this.planedDeliveryDate = planedDeliveryDate;
    }

    public String getExpectedSendDate() {
        return expectedSendDate;
    }

    public void setExpectedSendDate(String expectedSendDate) {
        this.expectedSendDate = expectedSendDate;
    }

    public String getForwardStore() {
        return forwardStore;
    }

    public void setForwardStore(String forwardStore) {
        this.forwardStore = forwardStore;
    }

    public String getHasMessageCard() {
        return hasMessageCard;
    }

    public void setHasMessageCard(String hasMessageCard) {
        this.hasMessageCard = hasMessageCard;
    }

    public String getReceiver() {
        return receiver;
    }

    public void setReceiver(String receiver) {
        this.receiver = receiver;
    }

    public String getReceiverPhone() {
        return receiverPhone;
    }

    public void setReceiverPhone(String receiverPhone) {
        this.receiverPhone = receiverPhone;
    }

    public String getReceiverCity() {
        return receiverCity;
    }

    public void setReceiverCity(String receiverCity) {
        this.receiverCity = receiverCity;
    }

    public String getReceiverAddress() {
        return receiverAddress;
    }

    public void setReceiverAddress(String receiverAddress) {
        this.receiverAddress = receiverAddress;
    }

    public List<TsOrderAiProductVO> getPackageProducts() {
        return packageProducts;
    }

    public void setPackageProducts(List<TsOrderAiProductVO> packageProducts) {
        this.packageProducts = packageProducts;
    }

}

==> beast-trans-api-2.3.7-20250312.034805-30-sources.jar: com/thebeastshop/trans/vo/order/ai/TsOrderAiPackageVO.java <==
package com.thebeastshop.trans.vo.order.ai;

import com.fasterxml.jackson.annotation.JsonProperty;
import com.thebeastshop.common.BaseDO;

import java.util.List;

/**
 * @author xiang.gao
 * @date 2025/3/10 19:17
 */
public class TsOrderAiPackageVO extends BaseDO {

    /**
     * 包裹序号
     */
    @JsonProperty("包裹")
    private String packageCode;

    /**
     * 包裹状态
     */
    @JsonProperty("包裹状态")
    private String packageStatus;

    /**
     * 配送信息
     */
    @JsonProperty("配送信息")
    private List<String> deliveryInfo;

    /**
     * 预计发货日期
     */
    @JsonProperty("预计发货日期")
    private String planedDeliveryDate;

    /**
     * 期望送达日期
     */
    @JsonProperty("期望送达日期")
    private String expectedSendDate;

    /**
     * 是否转门店
     */
    @JsonProperty("是否转门店")
    private String forwardStore;

    /**
     * 是否有留言卡
     */
    @JsonProperty("是否有留言卡")
    private String hasMessageCard;

    /**
     * 收货人
     */
    @JsonProperty("收货人")
    private String receiver;

    /**
     * 收货电话
     */
    @JsonProperty("收货电话")
    private String receiverPhone;

    /**
     * 收货城市
     */
    @JsonProperty("收货城市")
    private String receiverCity;

    /**
     * 收获地址
     */
    @JsonProperty("收获地址")
    private String receiverAddress;

    /**
     * 商品信息
     */
    @JsonProperty("商品信息")
    private List<TsOrderAiProductVO> packageProducts;

    public String getPackageCode() {
        return packageCode;
    }

    public void setPackageCode(String packageCode) {
        this.packageCode = packageCode;
    }

    public String getPackageStatus() {
        return packageStatus;
    }

    public void setPackageStatus(String packageStatus) {
        this.packageStatus = packageStatus;
    }

    public List<String> getDeliveryInfo() {
        return deliveryInfo;
    }

    public void setDeliveryInfo(List<String> deliveryInfo) {
        this.deliveryInfo = deliveryInfo;
    }

    public String getPlanedDeliveryDate() {
        return planedDeliveryDate;
    }

    public void setPlanedDeliveryDate(String planedDeliveryDate) {
        this.planedDeliveryDate = planedDeliveryDate;
    }

    public String getExpectedSendDate() {
        return expectedSendDate;
    }

    public void setExpectedSendDate(String expectedSendDate) {
        this.expectedSendDate = expectedSendDate;
    }

    public String getForwardStore() {
        return forwardStore;
    }

    public void setForwardStore(String forwardStore) {
        this.forwardStore = forwardStore;
    }

    public String getHasMessageCard() {
        return hasMessageCard;
    }

    public void setHasMessageCard(String hasMessageCard) {
        this.hasMessageCard = hasMessageCard;
    }

    public String getReceiver() {
        return receiver;
    }

    public void setReceiver(String receiver) {
        this.receiver = receiver;
    }

    public String getReceiverPhone() {
        return receiverPhone;
    }

    public void setReceiverPhone(String receiverPhone) {
        this.receiverPhone = receiverPhone;
    }

    public String getReceiverCity() {
        return receiverCity;
    }

    public void setReceiverCity(String receiverCity) {
        this.receiverCity = receiverCity;
    }

    public String getReceiverAddress() {
        return receiverAddress;
    }

    public void setReceiverAddress(String receiverAddress) {
        this.receiverAddress = receiverAddress;
    }

    public List<TsOrderAiProductVO> getPackageProducts() {
        return packageProducts;
    }

    public void setPackageProducts(List<TsOrderAiProductVO> packageProducts) {
        this.packageProducts = packageProducts;
    }

}
